Skip to contents

Download species indicators data including Center of Gravity metrics

Usage

dm_get_indicators(...)

Arguments

...

key = value pairs for filtering; where key could be any of the fields in the indicators table

Value

A sf object with indicators data

Examples

# Get indicators data for American Lobster in Northeast US Spring
tbl_lobster_indicators <- dm_get_indicators(
  common_name = "American lobster",
  region      = "Northeast US",
  season      = "Spring")
#> Loading required package: arcgisutils
#> 
#> Attaching package: ‘arcgisutils’
#> The following object is masked from ‘package:base’:
#> 
#>     %||%
tbl_lobster_indicators
#> # A tibble: 46 × 27
#>    objectid dataset_code region       season date_code species       common_name
#>       <int> <chr>        <chr>        <chr>  <chr>     <chr>         <chr>      
#>  1     9866 NEUS_SPR     Northeast US Spring 20240701  Homarus amer… American l…
#>  2     9867 NEUS_SPR     Northeast US Spring 20240701  Homarus amer… American l…
#>  3     9868 NEUS_SPR     Northeast US Spring 20240701  Homarus amer… American l…
#>  4     9869 NEUS_SPR     Northeast US Spring 20240701  Homarus amer… American l…
#>  5     9870 NEUS_SPR     Northeast US Spring 20240701  Homarus amer… American l…
#>  6     9871 NEUS_SPR     Northeast US Spring 20240701  Homarus amer… American l…
#>  7     9872 NEUS_SPR     Northeast US Spring 20240701  Homarus amer… American l…
#>  8     9873 NEUS_SPR     Northeast US Spring 20240701  Homarus amer… American l…
#>  9     9874 NEUS_SPR     Northeast US Spring 20240701  Homarus amer… American l…
#> 10     9875 NEUS_SPR     Northeast US Spring 20240701  Homarus amer… American l…
#> # ℹ 36 more rows
#> # ℹ 20 more variables: core_species <chr>, year <int>,
#> #   distribution_project_name <chr>, distribution_project_code <chr>,
#> #   summary_product <chr>, center_of_gravity_latitude <dbl>,
#> #   minimum_latitude <dbl>, maximum_latitude <dbl>, offset_latitude <dbl>,
#> #   center_of_gravity_latitude_se <dbl>, center_of_gravity_longitude <dbl>,
#> #   minimum_longitude <dbl>, maximum_longitude <dbl>, offset_longitude <dbl>, …